"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.project = project;
exports.unproject = unproject;

var _leaflet = require("leaflet");

var worldWidth = 1;
var worldHeight = 1;
var origin = new _leaflet.Point(0, 0);
var unitsPerLonDegree = worldWidth / 360;
var unitsPerLatRadian = worldHeight / (2 * Math.PI);

var degreesToRadians = function degreesToRadians(deg) {
  return deg * (Math.PI / 180);
};

var radiansToDegrees = function radiansToDegrees(rad) {
  return rad / (Math.PI / 180);
};
/**
 * Translate a location given as a LatLng to a point in world coordinates.
 *
 * The implementation is a simple mercator projection with rectangular
 * layout. Lat,lon and the resulting point are rotated depending on the
 * heading.
 */


function project(_ref) {
  var lat = _ref.lat,
      lng = _ref.lng;
  var x = origin.x + lng * unitsPerLonDegree;
  var siny = Math.sin(degreesToRadians(lat));
  var y = origin.y + 1 / 2 * Math.log((1 + siny) / (1 - siny)) * -unitsPerLatRadian;
  return new _leaflet.Point(x, y);
}
/**
 * Translate a location given as point in world coordinates to lat, lng.
 *
 * The implementation is a simple mercator projection with rectangular
 * layout. The given point and the resulting lat,lon are rotated depending
 * on the heading.
 */


function unproject(_ref2) {
  var x = _ref2.x,
      y = _ref2.y;
  var lng = (x - origin.x) / unitsPerLonDegree;
  var latRadians = (y - origin.y) / -unitsPerLatRadian;
  var lat = radiansToDegrees(2 * Math.atan(Math.exp(latRadians)) - Math.PI / 2);
  return new _leaflet.LatLng(lat, lng);
}